pecos.qeclib.qubit.sq\_sqrt\_paulis
===================================

.. automodule:: pecos.qeclib.qubit.sq_sqrt_paulis











   .. rubric:: Classes

   .. autosummary::

      S
      SX
      SXdg
      SY
      SYdg
      SZ
      SZdg
      Sdg
